---------------------------------------------------------------------------
--
-- Licensed Materials - Property of IBM
-- 5724-T05
--
-- (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
---------------------------------------------------------------------------

set serveroutput on size 1000000
-- This script is a part of 4.2.1.0.1 - 4.2.1.0-TIV-PROSPECT-ERCIPW-IF0001
--
-- 4.2.1.0.1 will check the definition of the affected entity table in the Ericsson IPWorks hierarchy
-- to make sure that the column defined for storing the IPNODE ID is at least 30
-- characters in size.
--
-- If the column is already configured as the minimum size or larger, then no changes will
-- be made, this is to avoid errors trying to resize the columns

DECLARE
  vCount       NUMBER;
  vSize        NUMBER;
BEGIN
  -- ENTITY: IPW_DnsServer.xml Table:ERIC_ENT_DNSSERVER Column: IPNODE_ID
  SELECT count(table_name) INTO vCount FROM user_tables WHERE table_name = 'ERIC_ENT_DNSSERVER';
  IF (vCount > 0) THEN
    -- Check existing size to make sure it is not changed adversely
    SELECT data_length INTO vSize FROM user_tab_columns
    WHERE table_name = 'ERIC_ENT_DNSSERVER'
    AND column_name = 'IPNODE_ID';

    -- if the length is appropriate, run the SQL and recompile the trigger which is made invalid.
    IF (vSize < 30) THEN
      run_sql(' ALTER TABLE ERIC_ENT_DNSSERVER MODIFY (IPNODE_ID VARCHAR2(30))');
      run_sql(' ALTER TRIGGER ERIC_ENT_DNSSERVER_biu compile');
    ELSE
      dbms_output.put_line('OK: ERIC_ENT_DNSSERVER - IPNODE_ID is already at min required size');
    END IF;
  ELSE
    dbms_output.put_line('Error: Unable to locate table ERIC_ENT_DNSSERVER in user_tables');
  END IF;

END;
/
COMMIT;
show errors;
EXIT;
